show: Print method for onions
Description
Show methods for onions
Usage
# S4 method for onion
show(object)
onion_show(x,h=getOption("show_onions_horizontally"))Arguments
- x,object
Onions
- h
Boolean, with default FALSE meaning to print
horizontally and TRUE meaning to print by columns.
Details
If options("horiz") is TRUE, then print by rows rather
than columns (provided that the default value of argument h is
not overridden). The default behaviour is to print by columns; do
this by setting horiz to anything other than TRUE, including
leaving it unset.